package
Version:
v0.0.0-...-33b106d
Opens a new window with list of versions in this module.
Published: Dec 2, 2017
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Job interface {
Revert() error
}
Job interface that supports a Revert() function
Source Files
¶
Click to show internal directories.
Click to hide internal directories.